@@ -23,7 +23,7 @@ _bohr_to_angstrom = 0.5291772
 _ry_to_ev = 13.605693009
 
 
-class QuestaalSite(object):
+class QuestaalSite:
     """Structure information: Questaal site.ext file
 
     Usually this will be instantiated with the
@@ -40,7 +40,7 @@ class QuestaalSite(object):
         xpos=True,
         read="fast",
         sites=None,
-        plat=[1, 0, 0, 0, 1, 0, 0, 0, 1],
+        plat=(1, 0, 0, 0, 1, 0, 0, 0, 1),
     ):
         sites = sites or []
         if nbas != len(sites):
@@ -56,7 +56,7 @@ class QuestaalSite(object):
         self.nbas, self.vn, self.io, self.alat = nbas, vn, io, alat
         self.xpos, self.read, self.sites, self.plat = xpos, read, sites, plat
 
-        is_empty = re.compile("E\d*$")
+        is_empty = re.compile(r"E\d*$")
         empty_sites = [
             site for site in sites if is_empty.match(site["species"]) is not None
         ]
@@ -134,7 +134,7 @@ class QuestaalSite(object):
         )
 
 
-class QuestaalInit(object):
+class QuestaalInit:
     """Structure information: Questaal init.ext file
 
     Usually this will be instantiated with the
@@ -248,12 +248,12 @@ class QuestaalInit(object):
                 )
                 self.lattice["GAMMA"] = 120
             else:
-                logging.info("Lattice angle GAMMA not given, " "assume right-angle")
+                logging.info("Lattice angle GAMMA not given, assume right-angle")
                 self.lattice["GAMMA"] = 90
 
         if self.cartesian:
             logging.info(
-                "Warning: Cartesian positions used without " "explicit lattice vectors"
+                "Warning: Cartesian positions used without explicit lattice vectors"
             )
 
         if "UNITS" not in self.lattice or self.lattice["UNITS"] is None:
@@ -299,7 +299,7 @@ class QuestaalInit(object):
             if "UNITS" not in self.lattice or self.lattice["UNITS"] is None:
                 lattice = Lattice(lattice.matrix * _bohr_to_angstrom)
                 coords = [
-                    tuple([x * _bohr_to_angstrom for x in site_coords])
+                    tuple(x * _bohr_to_angstrom for x in site_coords)
                     for site_coords in coords
                 ]
 
@@ -319,31 +319,29 @@ class QuestaalInit(object):
                     f.write("    PLAT= " + " ".join(map(str, lattice_params)))
                     f.write("\n")
                 else:
-                    f.write("    {0}={1}\n".format(key, value))
+                    f.write(f"    {key}={value}\n")
 
             f.write("SITE\n")
             for row in self.site:
-                f.write("    ATOM={0:4s}  ".format(row["ATOM"]))
+                f.write(f"    ATOM={row['ATOM']:4s}  ")
                 if "POS" in self.site:
-                    f.write("POS= {0:11.8f} {1:11.8f} {2:11.8f}".format(*row["POS"]))
+                    f.write("POS= {:11.8f} {:11.8f} {:11.8f}".format(*row["POS"]))
                 else:
-                    f.write("X= {0:11.8f} {1:11.8f} {2:11.8f}".format(*row["X"]))
+                    f.write("X= {:11.8f} {:11.8f} {:11.8f}".format(*row["X"]))
                 for key, value in row.items():
                     if key not in ("ATOM", "POS", "X"):
-                        f.write("  {0}= {1}".format(key, value))
+                        f.write(f"  {key}= {value}")
                 f.write("\n")
 
             if self.spec is not None:
                 f.write("SPEC")
                 for key, value in self.spec.items():
-                    f.write("  {0}= {1}\n".format(key, value))
+                    f.write(f"  {key}= {value}\n")
 
     @staticmethod
     def from_structure(structure):
         """Generate QuestaalInit object from pymatgen structure"""
-        lattice = {"ALAT": 1, "UNITS": "A"}
-        lattice["PLAT"] = structure.lattice.matrix
-
+        lattice = {"ALAT": 1, "UNITS": "A", "PLAT": structure.lattice.matrix}
         sites = [
             {"ATOM": site.species_string, "X": tuple(site.frac_coords)}
             for site in structure.sites
@@ -480,7 +478,7 @@ class QuestaalInit(object):
                 for unsupported_param in unsupported_params:
                     if unsupported_param in tag_dict:
                         raise NotImplementedError(
-                            "Questaal tag {0}_{1} is not supported".format(
+                            "Questaal tag {}_{} is not supported".format(
                                 category, unsupported_param
                             )
                         )
@@ -499,13 +497,12 @@ def write_kpoint_files(
     filename,
     kpoints,
     labels,
-    alat=1,
     make_folders=False,
     directory=None,
     cart_coords=False,
-    **kwargs
+    **kwargs,
 ):
-    """Write syml file for Questaal kpoints
+    r"""Write syml file for Questaal kpoints
 
     The interface imitates the VASP KPOINTS file writer for simplicity of
     integration into Sumo, but there are some conceptual differences:
@@ -544,12 +541,12 @@ def write_kpoint_files(
     for key, value in kwargs.items():
         if value is not None:
             logging.info(
-                'Ignoring k-point write option "{0}"; not '
+                'Ignoring k-point write option "{}"; not '
                 "implemented for Questaal calculations.".format(key)
             )
 
     ext = filename.split(".")[-1]
-    logging.info("System id from init filename: {0}".format(ext))
+    logging.info(f"System id from init filename: {ext}")
 
     if directory is not None:
         path = directory
@@ -563,7 +560,9 @@ def write_kpoint_files(
             makedirs(path)
         except OSError as e:
             if e.errno == errno.EEXIST:
-                logging.error("\nERROR: Folders already exist, won't " "overwrite.")
+                import sys
+
+                logging.error("\nERROR: Folders already exist, won't overwrite.")
                 sys.exit()
             else:
                 raise
@@ -582,11 +581,9 @@ def write_kpoint_files(
     if labels is None:
         with open(os.path.join(path, "syml." + ext), "w") as f:
             for kpt in kpoints:
-                f.write(
-                    "{0:11.8f} {1:11.8f} {2:11.8f}\n".format(kpt[0], kpt[1], kpt[2])
-                )
+                f.write(f"{kpt[0]:11.8f} {kpt[1]:11.8f} {kpt[2]:11.8f}\n")
     else:
-        label_positions = [i for i, l in enumerate(labels) if l != ""]
+        label_positions = [i for i, label in enumerate(labels) if label != ""]
         special_points = [kpoints[i] for i in label_positions]
         segment_samples = [
             label_positions[i + 1] - label_positions[i] + 1
@@ -597,8 +594,8 @@ def write_kpoint_files(
                 if samples == 2:
                     continue  # Don't add segments between branches
                 f.write(
-                    "{0:5d}    {1:11.8f} {2:11.8f} {3:11.8f}    "
-                    "{4:11.8f} {5:11.8f} {6:11.8f}    {7} to {8}\n".format(
+                    "{:5d}    {:11.8f} {:11.8f} {:11.8f}    "
+                    "{:11.8f} {:11.8f} {:11.8f}    {} to {}\n".format(
                         samples,
                         special_points[i][0],
                         special_points[i][1],
@@ -634,7 +631,7 @@ def labels_from_syml(syml_file):
     """
     labels = {}
 
-    with open(syml_file, "r") as f:
+    with open(syml_file) as f:
         lines = f.readlines()
     for line in lines:
         npts, x1, y1, z1, x2, y2, z2, *label_text = line.split()
@@ -648,8 +645,7 @@ def labels_from_syml(syml_file):
             label1_label2 = label_text.split(" to ")
             if len(label1_label2) != 2:
                 raise ValueError(
-                    "Not clear how to interpret labels from "
-                    "this line: {}".format(line)
+                    f"Not clear how to interpret labels from this line: {line}"
                 )
             label1, label2 = label1_label2
             labels.update({label1: kpt1, label2: kpt2})
@@ -758,16 +754,15 @@ def read_dos(
 
             if check_tdos and int(nchan) != 1:
                 raise ValueError(
-                    "File {} is not a TDOS: contains {} channels"
-                    "".format(filename, nchan)
+                    f"File {filename} is not a TDOS: contains {nchan} channels"
                 )
 
             ne, nchan, nsp, fmt = map(int, (ne, nchan, nsp, fmt))
             emin, emax, efermi, delta = map(float, (emin, emax, efermi, delta))
             if ry:
-                emin, emax, efermi, delta = [
+                emin, emax, efermi, delta = (
                     x * _ry_to_ev for x in (emin, emax, efermi, delta)
-                ]
+                )
 
             nlines = ceil(ne / 5)
             data = [_read_states(f, nlines) for _ in range(nsp * nchan)]
@@ -787,7 +782,7 @@ def read_dos(
             densities = {Spin.up: data[0], Spin.down: data[1]}
         else:
             raise ValueError(
-                "There can't be {} spin channels, that makes " "no sense!".format(nsp)
+                f"There can't be {nsp} spin channels, that makes no sense!"
             )
         return Dos(efermi, energies, densities)
 
@@ -805,7 +800,7 @@ def read_dos(
             spins = (Spin.up, Spin.down)
         else:
             raise ValueError(
-                "There can't be {} spin channels, that makes " "no sense!".format(nsp)
+                f"There can't be {nsp} spin channels, that makes no sense!"
             )
 
         site_data = QuestaalSite.from_file(site_file)
@@ -872,14 +867,14 @@ def read_dos(
             cdos, lm_orbitals=lm_orbitals, atoms=atoms, elements=elements
         )
 
-    return (tdos, pdos)
+    return tdos, pdos
 
 
 def band_structure(bnds_file, lattice, labels=None, alat=1, coords_are_cartesian=False):
     """Read band structure data
 
     Args:
-        bands_file (:obj:`str`): Path to questaal bnds.ext output file. The
+        bnds_file (:obj:`str`): Path to questaal bnds.ext output file. The
             k-point positions and eigenvalues are read from this file.
         labels (:obj:`dict`): Dict of special point locations and labels. This
             is generally obtained from a syml.ext file using
@@ -943,7 +938,7 @@ def band_structure(bnds_file, lattice, labels=None, alat=1, coords_are_cartesian
 
     # Key info has been collected: re-read file for kpts and eigenvalues
     def _read_eigenvals(f, nlines):
-        lines = [f.readline() for i in range(nlines)]
+        lines = [f.readline() for _ in range(nlines)]
         # This statement is very "functional programming"; read it
         # backwards.  List of split lines is "flattened" by chain into
         # iterator of values; this is fed into map to make floats and
@@ -977,7 +972,7 @@ def band_structure(bnds_file, lattice, labels=None, alat=1, coords_are_cartesian
 
             block_nkpts = int(f.readline().strip())
             if spin_pol:
-                block_nkpts = block_nkpts // 2
+                block_nkpts //= 2
 
     # Transpose matrix to arrange by band and convert to eV from Ry
     eigenvals = {key: np.array(data).T * _ry_to_ev for key, data in eigenvals.items()}
@@ -991,7 +986,7 @@ def band_structure(bnds_file, lattice, labels=None, alat=1, coords_are_cartesian
     labels = labels or {}  # Initialise a dict if null value
     # (Avoids oddness with mutable option defaults)
     if coords_are_cartesian:
-        logging.info("Cartesian coordinates, scaling by ALAT = {}".format(alat))
+        logging.info(f"Cartesian coordinates, scaling by ALAT = {alat}")
         for label, coords in labels.items():
             labels[label] = np.array(coords) / (alat * _bohr_to_angstrom)
     else:
@@ -1000,7 +995,6 @@ def band_structure(bnds_file, lattice, labels=None, alat=1, coords_are_cartesian
                 coords, lattice.reciprocal_lattice_crystallographic.matrix
             )
 
-    raise Exception(eigenvals)
     # Data in bnds file seems to always be Cartesian
     return BandStructureSymmLine(
         kpoints,
@@ -1027,12 +1021,12 @@ def dielectric_from_file(filename, out_filename=None):
     """
 
     if "eps_BSE" in filename:
-        return dielectric_from_BSE(filename)
+        return dielectric_from_bse(filename)
     else:
         return dielectric_from_opt(filename, out_filename=out_filename)
 
 
-def dielectric_from_BSE(filename):
+def dielectric_from_bse(filename):
     """Read a Questaal eps_BSE.out file and return dielectric function
 
     eps_BSE files only provide a scalar complex number; this is converted to a
@@ -1079,7 +1073,7 @@ def dielectric_from_BSE(filename):
     real = [[r, r, r, 0, 0, 0] for r in data[:, 1]]
     imag = [[i, i, i, 0, 0, 0] for i in data[:, 2]]
 
-    return (energy, real, imag)
+    return energy, real, imag
 
 
 def dielectric_from_opt(filename, cshift=1e-6, out_filename=None):
@@ -1130,13 +1124,13 @@ def dielectric_from_opt(filename, cshift=1e-6, out_filename=None):
         data = np.hstack(data[:, :1], data[1:4] + data[4:7])
     else:
         raise ValueError(
-            "Not sure how to interpret {}; expected " "4 or 7 columns.".format(filename)
+            f"Not sure how to interpret {filename}; expected 4 or 7 columns."
         )
 
     data[:, 0] *= _ry_to_ev
     de = data[1, 0] - data[0, 0]
     eps_imag = [[[row[1], 0, 0], [0, row[2], 0], [0, 0, row[3]]] for row in data]
-    eps_real = kkr(de, eps_imag)
+    eps_real = kkr(de, eps_imag, cshift=cshift)
 
     # Re-shape to XX YY ZZ XY YZ XZ format
     eps_imag = np.array(eps_imag).reshape(len(eps_imag), 9)
@@ -1150,4 +1144,4 @@ def dielectric_from_opt(filename, cshift=1e-6, out_filename=None):
                 f.write((" ".join(["{:10.8f}"] * 7)).format(e, *r[:3], *i[:3]))
                 f.write("\n")
 
-    return (data[:, 0].flatten(), eps_real, eps_imag)
+    return data[:, 0].flatten(), eps_real, eps_imag
