@@ -1,4 +1,3 @@
-# coding: utf-8
 # Copyright (c) Scanlon Materials Theory Group
 # Distributed under the terms of the MIT License.
 
@@ -6,8 +5,9 @@
 Package containing functions for symmetry and k-point paths.
 """
 
-from sumo.symmetry.kpath import Kpath
+from sumo.symmetry.kpath import Kpath  # isort:skip
 from sumo.symmetry.brad_crack_kpath import BradCrackKpath
+from sumo.symmetry.custom_kpath import CustomKpath
+from sumo.symmetry.latimer_munro_kpath import LatimerKpath
 from sumo.symmetry.pymatgen_kpath import PymatgenKpath
 from sumo.symmetry.seekpath_kpath import SeekpathKpath
-from sumo.symmetry.custom_kpath import CustomKpath
